@@ -2,7 +2,6 @@
  * File:        paragraphs.cpp
  * Description: Paragraph detection for tesseract.
  * Author:      David Eger
- * Created:     25 February 2011
  *
  * (C) Copyright 2011, Google Inc.
  ** Licensed under the Apache License, Version 2.0 (the "License");
@@ -52,9 +51,9 @@ namespace tesseract {
 
 // Special "weak" ParagraphModels.
 const ParagraphModel *kCrownLeft
-    = reinterpret_cast<ParagraphModel *>(0xDEAD111F);
+    = reinterpret_cast<ParagraphModel *>(static_cast<uintptr_t>(0xDEAD111F));
 const ParagraphModel *kCrownRight
-    = reinterpret_cast<ParagraphModel *>(0xDEAD888F);
+    = reinterpret_cast<ParagraphModel *>(static_cast<uintptr_t>(0xDEAD888F));
 
 // Do the text and geometry of two rows support a paragraph break between them?
 static bool LikelyParagraphStart(const RowScratchRegisters &before,
@@ -868,8 +867,7 @@ struct GeometricClassifierState {
   GeometricClassifierState(int dbg_level,
                            GenericVector<RowScratchRegisters> *r,
                            int r_start, int r_end)
-      : debug_level(dbg_level), rows(r), row_start(r_start), row_end(r_end),
-        margin(0) {
+      : debug_level(dbg_level), rows(r), row_start(r_start), row_end(r_end) {
     tolerance = InterwordSpace(*r, r_start, r_end);
     CalculateTabStops(r, r_start, r_end, tolerance,
                       &left_tabs, &right_tabs);
@@ -938,20 +936,20 @@ struct GeometricClassifierState {
   }
 
   // We print out messages with a debug level at least as great as debug_level.
-  int debug_level;
+  int debug_level = 0;
 
   // The Geometric Classifier was asked to find a single paragraph model
   // to fit the text rows (*rows)[row_start, row_end)
   GenericVector<RowScratchRegisters> *rows;
-  int row_start;
-  int row_end;
+  int row_start = 0;
+  int row_end = 0;
 
   // The amount by which we expect the text edge can vary and still be aligned.
-  int tolerance;
+  int tolerance = 0;
 
   // Is the script in this text block left-to-right?
   // HORRIBLE ROUGH APPROXIMATION.  TODO(eger): Improve
-  bool ltr;
+  bool ltr = false;
 
   // These left and right tab stops were determined to be the common tab
   // stops for the given text.
@@ -959,13 +957,13 @@ struct GeometricClassifierState {
   GenericVector<Cluster> right_tabs;
 
   // These are parameters we must determine to create a ParagraphModel.
-  tesseract::ParagraphJustification just;
-  int margin;
-  int first_indent;
-  int body_indent;
+  tesseract::ParagraphJustification just = JUSTIFICATION_UNKNOWN;
+  int margin = 0;
+  int first_indent = 0;
+  int body_indent = 0;
 
   // eop_threshold > 0 if the text is fully justified.  See MarkRowsWithModel()
-  int eop_threshold;
+  int eop_threshold = 0;
 };
 
 // Given a section of text where strong textual clues did not help identifying
@@ -1229,7 +1227,7 @@ const ParagraphModel *ParagraphTheory::AddModel(const ParagraphModel &model) {
     if ((*models_)[i]->Comparable(model))
       return (*models_)[i];
   }
-  ParagraphModel *m = new ParagraphModel(model);
+  auto *m = new ParagraphModel(model);
   models_->push_back(m);
   models_we_added_.push_back_new(m);
   return m;
@@ -2444,7 +2442,7 @@ static void InitializeRowInfo(bool after_recognition,
   info->rword_likely_starts_idea = false;
   info->rword_likely_ends_idea = false;
   info->has_leaders = false;
-  info->ltr = 1;
+  info->ltr = true;
 
   if (!after_recognition) {
     InitializeTextAndBoxesPreRecognition(it, info);
