@@ -126,7 +126,9 @@ BLOB_CHOICE::BLOB_CHOICE(const BLOB_CHOICE &other) : ELIST_LINK(other) {
   max_xheight_ = other.max_xheight_;
   yshift_ = other.yshift();
   classifier_ = other.classifier_;
+#ifndef DISABLED_LEGACY_ENGINE
   fonts_ = other.fonts_;
+#endif  // ndef DISABLED_LEGACY_ENGINE
 }
 
 // Copy assignment operator.
@@ -143,7 +145,9 @@ BLOB_CHOICE& BLOB_CHOICE::operator=(const BLOB_CHOICE& other) {
   max_xheight_ = other.max_xheight_;
   yshift_ = other.yshift();
   classifier_ = other.classifier_;
+#ifndef DISABLED_LEGACY_ENGINE
   fonts_ = other.fonts_;
+#endif  // ndef DISABLED_LEGACY_ENGINE
   return *this;
 }
 
@@ -555,10 +559,7 @@ void WERD_CHOICE::SetScriptPositions(bool small_caps, TWERD* word, int debug) {
     return;
   }
 
-  int position_counts[4];
-  for (int i = 0; i < 4; i++) {
-    position_counts[i] = 0;
-  }
+  int position_counts[4] = { 0, 0, 0, 0 };
 
   int chunk_index = 0;
   for (int blob_index = 0; blob_index < length_; ++blob_index, ++chunk_index) {
@@ -789,7 +790,7 @@ void WERD_CHOICE::DisplaySegmentation(TWERD* word) {
   TBOX bbox;
   int blob_index = 0;
   for (int c = 0; c < length_; ++c) {
-    ScrollView::Color color =
+    auto color =
         static_cast<ScrollView::Color>(c % kNumColors + 3);
     for (int i = 0; i < state_[c]; ++i, ++blob_index) {
       TBLOB* blob = word->blobs[blob_index];
