@@ -2,7 +2,6 @@
  * File:        elst.h  (Formerly elist.h)
  * Description: Embedded list module include file.
  * Author:      Phil Cheatle
- * Created:     Mon Jan 07 08:35:34 GMT 1991
  *
  * (C) Copyright 1991, Hewlett-Packard Ltd.
  ** Licensed under the Apache License, Version 2.0 (the "License");
@@ -21,7 +20,6 @@
 #define ELST_H
 
 #include <cstdio>
-#include "host.h"
 #include "serialis.h"
 #include "lsterr.h"
 
@@ -49,11 +47,6 @@ The following list types and iterators are provided:
               CLIST_LINK
     (Single linked)
 
-    Cons List           CLIST2
-              CLIST2_ITERATOR
-              CLIST2_LINK
-    (Double linked)
-
 An embedded list is where the list pointers are provided by a generic class.
 Data types to be listed inherit from the generic class.  Data is thus linked
 in only ONE list at any one time.
@@ -192,14 +185,10 @@ class DLLSYM ELIST_ITERATOR
   ELIST_LINK *prev;              //prev element
   ELIST_LINK *current;           //current element
   ELIST_LINK *next;              //next element
-  bool ex_current_was_last;     //current extracted
-  //was end of list
-  bool ex_current_was_cycle_pt; //current extracted
-  //was cycle point
-  ELIST_LINK *cycle_pt;          //point we are cycling
-  //the list to.
-  bool started_cycling;         //Have we moved off
-  //the start?
+  ELIST_LINK *cycle_pt;          //point we are cycling the list to.
+  bool ex_current_was_last;      //current extracted was end of list
+  bool ex_current_was_cycle_pt;  //current extracted was cycle point
+  bool started_cycling;          //Have we moved off the start?
 
   ELIST_LINK *extract_sublist(                            //from this current...
                               ELIST_ITERATOR *other_it);  //to other current
@@ -307,9 +296,9 @@ inline void ELIST_ITERATOR::set_to_list(  //change list
   current = list->First ();
   next = current ? current->next : nullptr;
   cycle_pt = nullptr;               //await explicit set
-  started_cycling = FALSE;
-  ex_current_was_last = FALSE;
-  ex_current_was_cycle_pt = FALSE;
+  started_cycling = false;
+  ex_current_was_last = false;
+  ex_current_was_cycle_pt = false;
 }
 
 
@@ -392,7 +381,7 @@ inline void ELIST_ITERATOR::add_after_stay_put(  // element to add
     new_element->next = new_element;
     list->last = new_element;
     prev = next = new_element;
-    ex_current_was_last = FALSE;
+    ex_current_was_last = false;
     current = nullptr;
   }
   else {
@@ -409,7 +398,7 @@ inline void ELIST_ITERATOR::add_after_stay_put(  // element to add
       prev->next = new_element;
       if (ex_current_was_last) {
         list->last = new_element;
-        ex_current_was_last = FALSE;
+        ex_current_was_last = false;
       }
     }
     next = new_element;
@@ -481,7 +470,7 @@ inline void ELIST_ITERATOR::add_before_stay_put(  // element to add
     new_element->next = new_element;
     list->last = new_element;
     prev = next = new_element;
-    ex_current_was_last = TRUE;
+    ex_current_was_last = true;
     current = nullptr;
   }
   else {
@@ -522,7 +511,7 @@ inline void ELIST_ITERATOR::add_list_after(ELIST *list_to_add) {
       list->last = list_to_add->last;
       prev = list->last;
       next = list->First ();
-      ex_current_was_last = TRUE;
+      ex_current_was_last = true;
       current = nullptr;
     }
     else {
@@ -537,7 +526,7 @@ inline void ELIST_ITERATOR::add_list_after(ELIST *list_to_add) {
         prev->next = list_to_add->First ();
         if (ex_current_was_last) {
           list->last = list_to_add->last;
-          ex_current_was_last = FALSE;
+          ex_current_was_last = false;
         }
         list_to_add->last->next = next;
         next = prev->next;
@@ -571,7 +560,7 @@ inline void ELIST_ITERATOR::add_list_before(ELIST *list_to_add) {
       prev = list->last;
       current = list->First ();
       next = current->next;
-      ex_current_was_last = FALSE;
+      ex_current_was_last = false;
     }
     else {
       prev->next = list_to_add->First ();
@@ -620,15 +609,11 @@ inline ELIST_LINK *ELIST_ITERATOR::extract() {
   } else {
     prev->next = next;           //remove from list
 
-    if (current == list->last) {
-      list->last = prev;
-      ex_current_was_last = TRUE;
-    } else {
-      ex_current_was_last = FALSE;
-    }
+    ex_current_was_last = (current == list->last);
+    if (ex_current_was_last) list->last = prev;
   }
   // Always set ex_current_was_cycle_pt so an add/forward will work in a loop.
-  ex_current_was_cycle_pt = (current == cycle_pt) ? TRUE : FALSE;
+  ex_current_was_cycle_pt = (current == cycle_pt);
   extracted_link = current;
   extracted_link->next = nullptr;   //for safety
   current = nullptr;
@@ -676,8 +661,8 @@ inline void ELIST_ITERATOR::mark_cycle_pt() {
   if (current)
     cycle_pt = current;
   else
-    ex_current_was_cycle_pt = TRUE;
-  started_cycling = FALSE;
+    ex_current_was_cycle_pt = true;
+  started_cycling = false;
 }
 
 
@@ -844,7 +829,7 @@ The macros generate:
   - An E_LIST_ITERATOR subclass:       CLASSNAME##_IT
 
 NOTE: Generated names are DELIBERATELY designed to clash with those for
-ELIST2IZE but NOT with those for CLISTIZE and CLIST2IZE
+ELIST2IZE but NOT with those for CLISTIZE.
 
 Two macros are provided: ELISTIZE and ELISTIZEH.
 The ...IZEH macros just define the class names for use in .h files
