@@ -19,7 +19,6 @@
           Include Files and Type Defines
 -----------------------------------------------------------------------------*/
 #include "kdtree.h"
-#include "cutil.h"      // for void_proc
 #include "emalloc.h"
 
 #include <algorithm>
@@ -69,11 +68,11 @@ class MinK {
   const Element* elements() { return elements_; }
 
  private:
-  const Key max_key_;   //< the maximum possible Key
-  Element *elements_;   //< unsorted array of elements
-  int elements_count_;  //< the number of results collected so far
-  int k_;               //< the number of results we want from the search
-  int max_index_;       //< the index of the result with the largest key
+  const Key max_key_;   ///< the maximum possible Key
+  Element *elements_;   ///< unsorted array of elements
+  int elements_count_;  ///< the number of results collected so far
+  int k_;               ///< the number of results we want from the search
+  int max_index_;       ///< the index of the result with the largest key
 };
 
 template<typename Key, typename Value>
@@ -132,8 +131,8 @@ class KDTreeSearch {
 
   KDTREE *tree_;
   float *query_point_;
-  float *sb_min_;  //< search box minimum
-  float *sb_max_;  //< search box maximum
+  float *sb_min_;  ///< search box minimum
+  float *sb_max_;  ///< search box maximum
   MinK<float, void *> results_;
 };
 
@@ -166,7 +165,7 @@ void KDTreeSearch::Search(int *result_count,
     for (int j = 0; j < count; j++) {
       // Pre-cast to float64 as key is a template type and we have no control
       // over its actual type.
-      distances[j] = (float)sqrt((double)results_.elements()[j].key);
+      distances[j] = static_cast<float>(sqrt(static_cast<double>(results_.elements()[j].key)));
       results[j] = results_.elements()[j].value;
     }
   }
@@ -179,8 +178,8 @@ void KDTreeSearch::Search(int *result_count,
 /// @param KeySize  # of dimensions in the K-D tree
 /// @param KeyDesc  array of params to describe key dimensions
 KDTREE *MakeKDTree(int16_t KeySize, const PARAM_DESC KeyDesc[]) {
-  KDTREE *KDTree = (KDTREE *) Emalloc(
-      sizeof(KDTREE) + (KeySize - 1) * sizeof(PARAM_DESC));
+  auto *KDTree = static_cast<KDTREE *>(Emalloc(
+      sizeof(KDTREE) + (KeySize - 1) * sizeof(PARAM_DESC)));
   for (int i = 0; i < KeySize; i++) {
     KDTree->KeyDesc[i].NonEssential = KeyDesc[i].NonEssential;
     KDTree->KeyDesc[i].Circular = KeyDesc[i].Circular;
@@ -233,7 +232,7 @@ void KDStore(KDTREE *Tree, float *Key, void *Data) {
     Node = *PtrToNode;
   }
 
-  *PtrToNode = MakeKDNode(Tree, Key, (void *) Data, Level);
+  *PtrToNode = MakeKDNode(Tree, Key, Data, Level);
 }                                /* KDStore */
 
 /**
@@ -328,7 +327,6 @@ void KDWalk(KDTREE *Tree, void_proc action, void *context) {
  * which are pointed to by the nodes.  This memory is left
  * untouched.
  * @param Tree  tree data structure to be released
- * @return none
  */
 void FreeKDTree(KDTREE *Tree) {
   FreeSubTree(Tree->Root.Left);
@@ -354,7 +352,7 @@ void FreeKDTree(KDTREE *Tree) {
 KDNODE *MakeKDNode(KDTREE *tree, float Key[], void *Data, int Index) {
   KDNODE *NewNode;
 
-  NewNode = (KDNODE *) Emalloc (sizeof (KDNODE));
+  NewNode = static_cast<KDNODE *>(Emalloc (sizeof (KDNODE)));
 
   NewNode->Key = Key;
   NewNode->Data = Data;
