@@ -27,7 +27,7 @@ namespace tesseract {
 
 class Image;
 
-Dict::Dict(CCUtil *ccutil)
+Dict::Dict(CCUtil* ccutil)
     : letter_is_okay_(&tesseract::Dict::def_letter_is_okay),
       probability_in_context_(&tesseract::Dict::def_probability_in_context),
       params_model_classify_(nullptr),
@@ -105,8 +105,6 @@ Dict::Dict(CCUtil *ccutil)
                  getCCUtil()->params()),
       INT_MEMBER(hyphen_debug_level, 0, "Debug level for hyphenated words.",
                  getCCUtil()->params()),
-      INT_MEMBER(max_viterbi_list_size, 10, "Maximum size of viterbi list.",
-                 getCCUtil()->params()),
       BOOL_MEMBER(use_only_first_uft8_step, false,
                   "Use only the first UTF8 step of the given string"
                   " when computing log probabilities.",
@@ -140,11 +138,6 @@ Dict::Dict(CCUtil *ccutil)
                     "Word for which stopper debug"
                     " information should be printed to stdout",
                     getCCUtil()->params()),
-      STRING_MEMBER(word_to_debug_lengths, "",
-                    "Lengths of unichars in word_to_debug",
-                    getCCUtil()->params()),
-      INT_MEMBER(fragments_debug, 0, "Debug character fragments",
-                 getCCUtil()->params()),
       BOOL_MEMBER(segment_nonalphabetic_script, false,
                   "Don't use any alphabetic-specific tricks."
                   " Set to true in the traineddata config file for"
@@ -166,8 +159,6 @@ Dict::Dict(CCUtil *ccutil)
                  " are specified, since overly generic patterns can result in"
                  " dawg search exploring an overly large number of options.",
                  getCCUtil()->params()) {
-  dang_ambigs_table_ = nullptr;
-  replace_ambigs_table_ = nullptr;
   reject_offset_ = 0.0;
   go_deeper_fxn_ = nullptr;
   hyphen_word_ = nullptr;
@@ -190,7 +181,7 @@ Dict::~Dict() {
   if (output_ambig_words_file_ != nullptr) fclose(output_ambig_words_file_);
 }
 
-DawgCache *Dict::GlobalDawgCache() {
+DawgCache* Dict::GlobalDawgCache() {
   // This global cache (a singleton) will outlive every Tesseract instance
   // (even those that someone else might declare as global statics).
   static DawgCache cache;
@@ -198,7 +189,7 @@ DawgCache *Dict::GlobalDawgCache() {
 }
 
 // Sets up ready for a Load or LoadLSTM.
-void Dict::SetupForLoad(DawgCache *dawg_cache) {
+void Dict::SetupForLoad(DawgCache* dawg_cache) {
   if (dawgs_.length() != 0) this->End();
 
   apostrophe_unichar_id_ = getUnicharset().unichar_to_id(kApostropheSymbol);
@@ -216,7 +207,7 @@ void Dict::SetupForLoad(DawgCache *dawg_cache) {
 }
 
 // Loads the dawgs needed by Tesseract. Call FinishLoad() after.
-void Dict::Load(const STRING &lang, TessdataManager *data_file) {
+void Dict::Load(const STRING& lang, TessdataManager* data_file) {
   // Load dawgs_.
   if (load_punc_dawg) {
     punc_dawg_ = dawg_cache_->GetSquishedDawg(lang, TESSDATA_PUNC_DAWG,
@@ -224,12 +215,12 @@ void Dict::Load(const STRING &lang, TessdataManager *data_file) {
     if (punc_dawg_) dawgs_ += punc_dawg_;
   }
   if (load_system_dawg) {
-    Dawg *system_dawg = dawg_cache_->GetSquishedDawg(
+    Dawg* system_dawg = dawg_cache_->GetSquishedDawg(
         lang, TESSDATA_SYSTEM_DAWG, dawg_debug_level, data_file);
     if (system_dawg) dawgs_ += system_dawg;
   }
   if (load_number_dawg) {
-    Dawg *number_dawg = dawg_cache_->GetSquishedDawg(
+    Dawg* number_dawg = dawg_cache_->GetSquishedDawg(
         lang, TESSDATA_NUMBER_DAWG, dawg_debug_level, data_file);
     if (number_dawg) dawgs_ += number_dawg;
   }
@@ -251,15 +242,14 @@ void Dict::Load(const STRING &lang, TessdataManager *data_file) {
   }
 
   STRING name;
-  if (((STRING &)user_words_suffix).length() > 0 ||
-      ((STRING &)user_words_file).length() > 0) {
-    Trie *trie_ptr = new Trie(DAWG_TYPE_WORD, lang, USER_DAWG_PERM,
+  if (!user_words_suffix.empty() || !user_words_file.empty()) {
+    Trie* trie_ptr = new Trie(DAWG_TYPE_WORD, lang, USER_DAWG_PERM,
                               getUnicharset().size(), dawg_debug_level);
-    if (((STRING &)user_words_file).length() > 0) {
-        name = user_words_file;
+    if (!user_words_file.empty()) {
+      name = user_words_file;
     } else {
-        name = getCCUtil()->language_data_path_prefix;
-        name += user_words_suffix;
+      name = getCCUtil()->language_data_path_prefix;
+      name += user_words_suffix;
     }
     if (!trie_ptr->read_and_add_word_list(name.string(), getUnicharset(),
                                           Trie::RRP_REVERSE_IF_HAS_RTL)) {
@@ -270,16 +260,15 @@ void Dict::Load(const STRING &lang, TessdataManager *data_file) {
     }
   }
 
-  if (((STRING &)user_patterns_suffix).length() > 0 ||
-      ((STRING &)user_patterns_file).length() > 0) {
-    Trie *trie_ptr = new Trie(DAWG_TYPE_PATTERN, lang, USER_PATTERN_PERM,
+  if (!user_patterns_suffix.empty() || !user_patterns_file.empty()) {
+    Trie* trie_ptr = new Trie(DAWG_TYPE_PATTERN, lang, USER_PATTERN_PERM,
                               getUnicharset().size(), dawg_debug_level);
     trie_ptr->initialize_patterns(&(getUnicharset()));
-    if (((STRING &)user_patterns_file).length() > 0) {
-        name = user_patterns_file;
+    if (!user_patterns_file.empty()) {
+      name = user_patterns_file;
     } else {
-        name = getCCUtil()->language_data_path_prefix;
-        name += user_patterns_suffix;
+      name = getCCUtil()->language_data_path_prefix;
+      name += user_patterns_suffix;
     }
     if (!trie_ptr->read_pattern_list(name.string(), getUnicharset())) {
       tprintf("Error: failed to load %s\n", name.string());
@@ -299,7 +288,7 @@ void Dict::Load(const STRING &lang, TessdataManager *data_file) {
 }
 
 // Loads the dawgs needed by the LSTM model. Call FinishLoad() after.
-void Dict::LoadLSTM(const STRING &lang, TessdataManager *data_file) {
+void Dict::LoadLSTM(const STRING& lang, TessdataManager* data_file) {
   // Load dawgs_.
   if (load_punc_dawg) {
     punc_dawg_ = dawg_cache_->GetSquishedDawg(lang, TESSDATA_LSTM_PUNC_DAWG,
@@ -307,15 +296,54 @@ void Dict::LoadLSTM(const STRING &lang, TessdataManager *data_file) {
     if (punc_dawg_) dawgs_ += punc_dawg_;
   }
   if (load_system_dawg) {
-    Dawg *system_dawg = dawg_cache_->GetSquishedDawg(
+    Dawg* system_dawg = dawg_cache_->GetSquishedDawg(
         lang, TESSDATA_LSTM_SYSTEM_DAWG, dawg_debug_level, data_file);
     if (system_dawg) dawgs_ += system_dawg;
   }
   if (load_number_dawg) {
-    Dawg *number_dawg = dawg_cache_->GetSquishedDawg(
+    Dawg* number_dawg = dawg_cache_->GetSquishedDawg(
         lang, TESSDATA_LSTM_NUMBER_DAWG, dawg_debug_level, data_file);
     if (number_dawg) dawgs_ += number_dawg;
   }
+
+  // stolen from Dict::Load (but needs params_ from Tesseract
+  // langdata/config/api):
+  STRING name;
+  if (!user_words_suffix.empty() || !user_words_file.empty()) {
+    Trie* trie_ptr = new Trie(DAWG_TYPE_WORD, lang, USER_DAWG_PERM,
+                              getUnicharset().size(), dawg_debug_level);
+    if (!user_words_file.empty()) {
+      name = user_words_file;
+    } else {
+      name = getCCUtil()->language_data_path_prefix;
+      name += user_words_suffix;
+    }
+    if (!trie_ptr->read_and_add_word_list(name.string(), getUnicharset(),
+                                          Trie::RRP_REVERSE_IF_HAS_RTL)) {
+      tprintf("Error: failed to load %s\n", name.string());
+      delete trie_ptr;
+    } else {
+      dawgs_ += trie_ptr;
+    }
+  }
+
+  if (!user_patterns_suffix.empty() || !user_patterns_file.empty()) {
+    Trie* trie_ptr = new Trie(DAWG_TYPE_PATTERN, lang, USER_PATTERN_PERM,
+                              getUnicharset().size(), dawg_debug_level);
+    trie_ptr->initialize_patterns(&(getUnicharset()));
+    if (!user_patterns_file.empty()) {
+      name = user_patterns_file;
+    } else {
+      name = getCCUtil()->language_data_path_prefix;
+      name += user_patterns_suffix;
+    }
+    if (!trie_ptr->read_pattern_list(name.string(), getUnicharset())) {
+      tprintf("Error: failed to load %s\n", name.string());
+      delete trie_ptr;
+    } else {
+      dawgs_ += trie_ptr;
+    }
+  }
 }
 
 // Completes the loading process after Load() and/or LoadLSTM().
@@ -327,13 +355,14 @@ bool Dict::FinishLoad() {
   // indices into the dawgs_ vector of the successors for dawg i.
   successors_.reserve(dawgs_.length());
   for (int i = 0; i < dawgs_.length(); ++i) {
-    const Dawg *dawg = dawgs_[i];
-    SuccessorList *lst = new SuccessorList();
+    const Dawg* dawg = dawgs_[i];
+    auto* lst = new SuccessorList();
     for (int j = 0; j < dawgs_.length(); ++j) {
-      const Dawg *other = dawgs_[j];
+      const Dawg* other = dawgs_[j];
       if (dawg != nullptr && other != nullptr &&
           (dawg->lang() == other->lang()) &&
-          kDawgSuccessors[dawg->type()][other->type()]) *lst += j;
+          kDawgSuccessors[dawg->type()][other->type()])
+        *lst += j;
     }
     successors_ += lst;
   }
@@ -341,8 +370,7 @@ bool Dict::FinishLoad() {
 }
 
 void Dict::End() {
-  if (dawgs_.length() == 0)
-    return;  // Not safe to call twice.
+  if (dawgs_.length() == 0) return;  // Not safe to call twice.
   for (int i = 0; i < dawgs_.size(); i++) {
     if (!dawg_cache_->FreeDawg(dawgs_[i])) {
       delete dawgs_[i];
@@ -364,19 +392,18 @@ void Dict::End() {
 // Returns true if in light of the current state unichar_id is allowed
 // according to at least one of the dawgs in the dawgs_ vector.
 // See more extensive comments in dict.h where this function is declared.
-int Dict::def_letter_is_okay(void* void_dawg_args,
-                             const UNICHARSET& unicharset,
-                             UNICHAR_ID unichar_id,
-                             bool word_end) const {
-  DawgArgs *dawg_args = static_cast<DawgArgs *>(void_dawg_args);
+int Dict::def_letter_is_okay(void* void_dawg_args, const UNICHARSET& unicharset,
+                             UNICHAR_ID unichar_id, bool word_end) const {
+  auto* dawg_args = static_cast<DawgArgs*>(void_dawg_args);
 
   ASSERT_HOST(unicharset.contains_unichar_id(unichar_id));
 
   if (dawg_debug_level >= 3) {
-    tprintf("def_letter_is_okay: current unichar=%s word_end=%d"
-            " num active dawgs=%d\n",
-            getUnicharset().debug_str(unichar_id).string(), word_end,
-            dawg_args->active_dawgs->length());
+    tprintf(
+        "def_letter_is_okay: current unichar=%s word_end=%d"
+        " num active dawgs=%d\n",
+        getUnicharset().debug_str(unichar_id).string(), word_end,
+        dawg_args->active_dawgs->length());
   }
 
   // Do not accept words that contain kPatternUnicharID.
@@ -397,9 +424,10 @@ int Dict::def_letter_is_okay(void* void_dawg_args,
   // with the updated ref (an edge with the corresponding unichar id) into
   // dawg_args->updated_pos.
   for (int a = 0; a < dawg_args->active_dawgs->length(); ++a) {
-    const DawgPosition &pos = (*dawg_args->active_dawgs)[a];
-    const Dawg *punc_dawg = pos.punc_index >= 0 ? dawgs_[pos.punc_index] : nullptr;
-    const Dawg *dawg = pos.dawg_index >= 0 ? dawgs_[pos.dawg_index] : nullptr;
+    const DawgPosition& pos = (*dawg_args->active_dawgs)[a];
+    const Dawg* punc_dawg =
+        pos.punc_index >= 0 ? dawgs_[pos.punc_index] : nullptr;
+    const Dawg* dawg = pos.dawg_index >= 0 ? dawgs_[pos.dawg_index] : nullptr;
 
     if (!dawg && !punc_dawg) {
       // shouldn't happen.
@@ -409,23 +437,23 @@ int Dict::def_letter_is_okay(void* void_dawg_args,
     if (!dawg) {
       // We're in the punctuation dawg.  A core dawg has not been chosen.
       NODE_REF punc_node = GetStartingNode(punc_dawg, pos.punc_ref);
-      EDGE_REF punc_transition_edge = punc_dawg->edge_char_of(
-          punc_node, Dawg::kPatternUnicharID, word_end);
+      EDGE_REF punc_transition_edge =
+          punc_dawg->edge_char_of(punc_node, Dawg::kPatternUnicharID, word_end);
       if (punc_transition_edge != NO_EDGE) {
         // Find all successors, and see which can transition.
-        const SuccessorList &slist = *(successors_[pos.punc_index]);
+        const SuccessorList& slist = *(successors_[pos.punc_index]);
         for (int s = 0; s < slist.length(); ++s) {
           int sdawg_index = slist[s];
-          const Dawg *sdawg = dawgs_[sdawg_index];
+          const Dawg* sdawg = dawgs_[sdawg_index];
           UNICHAR_ID ch = char_for_dawg(unicharset, unichar_id, sdawg);
           EDGE_REF dawg_edge = sdawg->edge_char_of(0, ch, word_end);
           if (dawg_edge != NO_EDGE) {
-            if (dawg_debug_level >=3) {
+            if (dawg_debug_level >= 3) {
               tprintf("Letter found in dawg %d\n", sdawg_index);
             }
             dawg_args->updated_dawgs->add_unique(
-                DawgPosition(sdawg_index, dawg_edge,
-                             pos.punc_index, punc_transition_edge, false),
+                DawgPosition(sdawg_index, dawg_edge, pos.punc_index,
+                             punc_transition_edge, false),
                 dawg_debug_level > 0,
                 "Append transition from punc dawg to current dawgs: ");
             if (sdawg->permuter() > curr_perm) curr_perm = sdawg->permuter();
@@ -435,16 +463,15 @@ int Dict::def_letter_is_okay(void* void_dawg_args,
           }
         }
       }
-      EDGE_REF punc_edge = punc_dawg->edge_char_of(punc_node, unichar_id,
-                                                   word_end);
+      EDGE_REF punc_edge =
+          punc_dawg->edge_char_of(punc_node, unichar_id, word_end);
       if (punc_edge != NO_EDGE) {
-        if (dawg_debug_level >=3) {
+        if (dawg_debug_level >= 3) {
           tprintf("Letter found in punctuation dawg\n");
         }
         dawg_args->updated_dawgs->add_unique(
             DawgPosition(-1, NO_EDGE, pos.punc_index, punc_edge, false),
-            dawg_debug_level > 0,
-            "Extend punctuation dawg: ");
+            dawg_debug_level > 0, "Extend punctuation dawg: ");
         if (PUNC_PERM > curr_perm) curr_perm = PUNC_PERM;
         if (punc_dawg->end_of_word(punc_edge)) dawg_args->valid_end = true;
       }
@@ -455,14 +482,15 @@ int Dict::def_letter_is_okay(void* void_dawg_args,
       // We can end the main word here.
       //  If we can continue on the punc ref, add that possibility.
       NODE_REF punc_node = GetStartingNode(punc_dawg, pos.punc_ref);
-      EDGE_REF punc_edge = punc_node == NO_EDGE ? NO_EDGE
-          : punc_dawg->edge_char_of(punc_node, unichar_id, word_end);
+      EDGE_REF punc_edge =
+          punc_node == NO_EDGE
+              ? NO_EDGE
+              : punc_dawg->edge_char_of(punc_node, unichar_id, word_end);
       if (punc_edge != NO_EDGE) {
         dawg_args->updated_dawgs->add_unique(
-            DawgPosition(pos.dawg_index, pos.dawg_ref,
-                         pos.punc_index, punc_edge, true),
-            dawg_debug_level > 0,
-            "Return to punctuation dawg: ");
+            DawgPosition(pos.dawg_index, pos.dawg_ref, pos.punc_index,
+                         punc_edge, true),
+            dawg_debug_level > 0, "Return to punctuation dawg: ");
         if (dawg->permuter() > curr_perm) curr_perm = dawg->permuter();
         if (punc_dawg->end_of_word(punc_edge)) dawg_args->valid_end = true;
       }
@@ -483,9 +511,11 @@ int Dict::def_letter_is_okay(void* void_dawg_args,
 
     // Find the edge out of the node for the unichar_id.
     NODE_REF node = GetStartingNode(dawg, pos.dawg_ref);
-    EDGE_REF edge = (node == NO_EDGE) ? NO_EDGE
-        : dawg->edge_char_of(node, char_for_dawg(unicharset, unichar_id, dawg),
-                             word_end);
+    EDGE_REF edge =
+        (node == NO_EDGE)
+            ? NO_EDGE
+            : dawg->edge_char_of(
+                  node, char_for_dawg(unicharset, unichar_id, dawg), word_end);
 
     if (dawg_debug_level >= 3) {
       tprintf("Active dawg: [%d, " REFFORMAT "] edge=" REFFORMAT "\n",
@@ -493,7 +523,7 @@ int Dict::def_letter_is_okay(void* void_dawg_args,
     }
 
     if (edge != NO_EDGE) {  // the unichar was found in the current dawg
-      if (dawg_debug_level >=3) {
+      if (dawg_debug_level >= 3) {
         tprintf("Letter found in dawg %d\n", pos.dawg_index);
       }
       if (word_end && punc_dawg && !punc_dawg->end_of_word(pos.punc_ref)) {
@@ -528,10 +558,10 @@ int Dict::def_letter_is_okay(void* void_dawg_args,
   return dawg_args->permuter;
 }
 
-void Dict::ProcessPatternEdges(const Dawg *dawg, const DawgPosition &pos,
+void Dict::ProcessPatternEdges(const Dawg* dawg, const DawgPosition& pos,
                                UNICHAR_ID unichar_id, bool word_end,
-                               DawgArgs *dawg_args,
-                               PermuterType *curr_perm) const {
+                               DawgArgs* dawg_args,
+                               PermuterType* curr_perm) const {
   NODE_REF node = GetStartingNode(dawg, pos.dawg_ref);
   // Try to find the edge corresponding to the exact unichar_id and to all the
   // edges corresponding to the character class of unichar_id.
@@ -543,9 +573,10 @@ void Dict::ProcessPatternEdges(const Dawg *dawg, const DawgPosition &pos,
     // On the first iteration check all the outgoing edges.
     // On the second iteration check all self-loops.
     for (int k = 0; k < 2; ++k) {
-      EDGE_REF edge = (k == 0)
-      ? dawg->edge_char_of(node, unichar_id_patterns[i], word_end)
-      : dawg->pattern_loop_edge(pos.dawg_ref, unichar_id_patterns[i], word_end);
+      EDGE_REF edge =
+          (k == 0) ? dawg->edge_char_of(node, unichar_id_patterns[i], word_end)
+                   : dawg->pattern_loop_edge(pos.dawg_ref,
+                                             unichar_id_patterns[i], word_end);
       if (edge == NO_EDGE) continue;
       if (dawg_debug_level >= 3) {
         tprintf("Pattern dawg: [%d, " REFFORMAT "] edge=" REFFORMAT "\n",
@@ -566,7 +597,7 @@ void Dict::ProcessPatternEdges(const Dawg *dawg, const DawgPosition &pos,
 // Fill the given active_dawgs vector with dawgs that could contain the
 // beginning of the word. If hyphenated() returns true, copy the entries
 // from hyphen_active_dawgs_ instead.
-void Dict::init_active_dawgs(DawgPositionVector *active_dawgs,
+void Dict::init_active_dawgs(DawgPositionVector* active_dawgs,
                              bool ambigs_mode) const {
   int i;
   if (hyphenated()) {
@@ -583,11 +614,11 @@ void Dict::init_active_dawgs(DawgPositionVector *active_dawgs,
   }
 }
 
-void Dict::default_dawgs(DawgPositionVector *dawg_pos_vec,
+void Dict::default_dawgs(DawgPositionVector* dawg_pos_vec,
                          bool suppress_patterns) const {
   bool punc_dawg_available =
-    (punc_dawg_ != nullptr) &&
-    punc_dawg_->edge_char_of(0, Dawg::kPatternUnicharID, true) != NO_EDGE;
+      (punc_dawg_ != nullptr) &&
+      punc_dawg_->edge_char_of(0, Dawg::kPatternUnicharID, true) != NO_EDGE;
 
   for (int i = 0; i < dawgs_.length(); i++) {
     if (dawgs_[i] != nullptr &&
@@ -610,7 +641,7 @@ void Dict::default_dawgs(DawgPositionVector *dawg_pos_vec,
   }
 }
 
-void Dict::add_document_word(const WERD_CHOICE &best_choice) {
+void Dict::add_document_word(const WERD_CHOICE& best_choice) {
   // Do not add hyphenated word parts to the document dawg.
   // hyphen_word_ will be non-nullptr after the set_hyphen_word() is
   // called when the first part of the hyphenated word is
@@ -621,8 +652,7 @@ void Dict::add_document_word(const WERD_CHOICE &best_choice) {
 
   int stringlen = best_choice.length();
 
-  if (valid_word(best_choice) || stringlen < 2)
-    return;
+  if (valid_word(best_choice) || stringlen < 2) return;
 
   // Discard words that contain >= kDocDictMaxRepChars repeating unichars.
   if (best_choice.length() >= kDocDictMaxRepChars) {
@@ -641,8 +671,7 @@ void Dict::add_document_word(const WERD_CHOICE &best_choice) {
 
   if (best_choice.certainty() < doc_dict_certainty_threshold ||
       stringlen == 2) {
-    if (best_choice.certainty() < doc_dict_pending_threshold)
-      return;
+    if (best_choice.certainty() < doc_dict_pending_threshold) return;
 
     if (!pending_words_->word_in_dawg(best_choice)) {
       if (stringlen > 2 ||
@@ -658,33 +687,30 @@ void Dict::add_document_word(const WERD_CHOICE &best_choice) {
   if (save_doc_words) {
     STRING filename(getCCUtil()->imagefile);
     filename += ".doc";
-    FILE *doc_word_file = fopen(filename.string(), "a");
+    FILE* doc_word_file = fopen(filename.string(), "a");
     if (doc_word_file == nullptr) {
       tprintf("Error: Could not open file %s\n", filename.string());
       ASSERT_HOST(doc_word_file);
     }
-    fprintf(doc_word_file, "%s\n",
-            best_choice.debug_string().string());
+    fprintf(doc_word_file, "%s\n", best_choice.debug_string().string());
     fclose(doc_word_file);
   }
   document_words_->add_word_to_dawg(best_choice);
 }
 
-void Dict::adjust_word(WERD_CHOICE *word,
-                       bool nonword,
+void Dict::adjust_word(WERD_CHOICE* word, bool nonword,
                        XHeightConsistencyEnum xheight_consistency,
-                       float additional_adjust,
-                       bool modify_rating,
+                       float additional_adjust, bool modify_rating,
                        bool debug) {
   bool is_han = (getUnicharset().han_sid() != getUnicharset().null_sid() &&
                  word->GetTopScriptID() == getUnicharset().han_sid());
-  bool case_is_ok = (is_han || case_ok(*word, getUnicharset()));
+  bool case_is_ok = (is_han || case_ok(*word));
   bool punc_is_ok = (is_han || !nonword || valid_punctuation(*word));
 
   float adjust_factor = additional_adjust;
   float new_rating = word->rating();
   new_rating += kRatingPad;
-  const char *xheight_triggered = "";
+  const char* xheight_triggered = "";
   if (word->length() > 1) {
     // Calculate x-height and y-offset consistency penalties.
     switch (xheight_consistency) {
@@ -709,8 +735,7 @@ void Dict::adjust_word(WERD_CHOICE *word,
   }
   if (debug) {
     tprintf("%sWord: %s %4.2f%s", nonword ? "Non-" : "",
-            word->unichar_string().string(), word->rating(),
-            xheight_triggered);
+            word->unichar_string().string(), word->rating(), xheight_triggered);
   }
 
   if (nonword) {  // non-dictionary word
@@ -750,8 +775,8 @@ void Dict::adjust_word(WERD_CHOICE *word,
   word->set_adjust_factor(adjust_factor);
 }
 
-int Dict::valid_word(const WERD_CHOICE &word, bool numbers_ok) const {
-  const WERD_CHOICE *word_ptr = &word;
+int Dict::valid_word(const WERD_CHOICE& word, bool numbers_ok) const {
+  const WERD_CHOICE* word_ptr = &word;
   WERD_CHOICE temp_word(word.unicharset());
   if (hyphenated() && hyphen_word_->unicharset() == word.unicharset()) {
     copy_hyphen_info(&temp_word);
@@ -761,15 +786,15 @@ int Dict::valid_word(const WERD_CHOICE &word, bool numbers_ok) const {
   if (word_ptr->length() == 0) return NO_PERM;
   // Allocate vectors for holding current and updated
   // active_dawgs and initialize them.
-  DawgPositionVector *active_dawgs = new DawgPositionVector[2];
+  auto* active_dawgs = new DawgPositionVector[2];
   init_active_dawgs(&(active_dawgs[0]), false);
   DawgArgs dawg_args(&(active_dawgs[0]), &(active_dawgs[1]), NO_PERM);
   int last_index = word_ptr->length() - 1;
   // Call letter_is_okay for each letter in the word.
   for (int i = hyphen_base_size(); i <= last_index; ++i) {
     if (!((this->*letter_is_okay_)(&dawg_args, *word_ptr->unicharset(),
-                                   word_ptr->unichar_id(i),
-                                   i == last_index))) break;
+                                   word_ptr->unichar_id(i), i == last_index)))
+      break;
     // Swap active_dawgs, constraints with the corresponding updated vector.
     if (dawg_args.updated_dawgs == &(active_dawgs[1])) {
       dawg_args.updated_dawgs = &(active_dawgs[0]);
@@ -780,12 +805,13 @@ int Dict::valid_word(const WERD_CHOICE &word, bool numbers_ok) const {
     }
   }
   delete[] active_dawgs;
-  return valid_word_permuter(dawg_args.permuter, numbers_ok) ?
-    dawg_args.permuter : NO_PERM;
+  return valid_word_permuter(dawg_args.permuter, numbers_ok)
+             ? dawg_args.permuter
+             : NO_PERM;
 }
 
-bool Dict::valid_bigram(const WERD_CHOICE &word1,
-                        const WERD_CHOICE &word2) const {
+bool Dict::valid_bigram(const WERD_CHOICE& word1,
+                        const WERD_CHOICE& word2) const {
   if (bigram_dawg_ == nullptr) return false;
 
   // Extract the core word from the middle of each word with any digits
@@ -821,13 +847,13 @@ bool Dict::valid_bigram(const WERD_CHOICE &word1,
   }
   WERD_CHOICE normalized_word(&uchset, bigram_string.size());
   for (int i = 0; i < bigram_string.size(); ++i) {
-    normalized_word.append_unichar_id_space_allocated(bigram_string[i], 1,
-                                                      0.0f, 0.0f);
+    normalized_word.append_unichar_id_space_allocated(bigram_string[i], 1, 0.0f,
+                                                      0.0f);
   }
   return bigram_dawg_->word_in_dawg(normalized_word);
 }
 
-bool Dict::valid_punctuation(const WERD_CHOICE &word) {
+bool Dict::valid_punctuation(const WERD_CHOICE& word) {
   if (word.length() == 0) return NO_PERM;
   int i;
   WERD_CHOICE new_word(word.unicharset());
@@ -841,21 +867,21 @@ bool Dict::valid_punctuation(const WERD_CHOICE &word) {
                !getUnicharset().get_isdigit(unichar_id)) {
       return false;  // neither punc, nor alpha, nor digit
     } else if ((new_len = new_word.length()) == 0 ||
-               new_word.unichar_id(new_len-1) != Dawg::kPatternUnicharID) {
+               new_word.unichar_id(new_len - 1) != Dawg::kPatternUnicharID) {
       new_word.append_unichar_id(Dawg::kPatternUnicharID, 1, 0.0, 0.0);
     }
   }
   for (i = 0; i < dawgs_.size(); ++i) {
-    if (dawgs_[i] != nullptr &&
-        dawgs_[i]->type() == DAWG_TYPE_PUNCTUATION &&
-        dawgs_[i]->word_in_dawg(new_word)) return true;
+    if (dawgs_[i] != nullptr && dawgs_[i]->type() == DAWG_TYPE_PUNCTUATION &&
+        dawgs_[i]->word_in_dawg(new_word))
+      return true;
   }
   return false;
 }
 
 /// Returns true if the language is space-delimited (not CJ, or T).
 bool Dict::IsSpaceDelimitedLang() const {
-  const UNICHARSET &u_set = getUnicharset();
+  const UNICHARSET& u_set = getUnicharset();
   if (u_set.han_sid() > 0) return false;
   if (u_set.katakana_sid() > 0) return false;
   if (u_set.thai_sid() > 0) return false;
