@@ -3,7 +3,6 @@
 // Description: Beam search to decode from the re-encoded CJK as a sequence of
 //              smaller numbers in place of a single large code.
 // Author:      Ray Smith
-// Created:     Fri Mar 13 09:39:01 PDT 2015
 //
 // (C) Copyright 2015, Google Inc.
 // Licensed under the Apache License, Version 2.0 (the "License");
@@ -25,24 +24,19 @@
 #include <deque>
 #include <map>
 #include <set>
+#include <tuple>
 #include <vector>
 
 #include <algorithm>
 
 namespace tesseract {
 
-// Clipping value for certainty inside Tesseract. Reflects the minimum value
-// of certainty that will be returned by ExtractBestPathAsUnicharIds.
-// Supposedly on a uniform scale that can be compared across languages and
-// engines.
-const float RecodeBeamSearch::kMinCertainty = -20.0f;
-
 // The beam width at each code position.
 const int RecodeBeamSearch::kBeamWidths[RecodedCharID::kMaxCodeLen + 1] = {
     5, 10, 16, 16, 16, 16, 16, 16, 16, 16,
 };
 
-const char* kNodeContNames[] = {"Anything", "OnlyDup", "NoDup"};
+static const char* kNodeContNames[] = {"Anything", "OnlyDup", "NoDup"};
 
 // Prints debug details of the node.
 void RecodeNode::Print(int null_char, const UNICHARSET& unicharset,
@@ -53,7 +47,7 @@ void RecodeNode::Print(int null_char, const UNICHARSET& unicharset,
     tprintf("label=%d, uid=%d=%s", code, unichar_id,
             unicharset.debug_str(unichar_id).string());
   }
-  tprintf(" score=%g, c=%g,%s%s%s perm=%d, hash=%lx", score, certainty,
+  tprintf(" score=%g, c=%g,%s%s%s perm=%d, hash=%" PRIx64, score, certainty,
           start_of_dawg ? " DawgStart" : "", start_of_word ? " Start" : "",
           end_of_word ? " End" : "", permuter, code_hash);
   if (depth > 0 && prev != nullptr) {
@@ -112,7 +106,6 @@ void RecodeBeamSearch::SaveMostCertainChoices(const float* outputs,
                                              const UNICHARSET* charset,
                                              int xCoord) {
   std::vector<std::pair<const char*, float>> choices;
-  int pos = 0;
   for (int i = 0; i < num_outputs; ++i) {
     if (outputs[i] >= 0.01f) {
       const char* character;
@@ -123,7 +116,7 @@ void RecodeBeamSearch::SaveMostCertainChoices(const float* outputs,
       } else {
         character = charset->id_to_unichar_ext(i);
       }
-      pos = 0;
+      size_t pos = 0;
       //order the possible choices within one timestep
       //beginning with the most likely
       while (choices.size() > pos && choices[pos].second > outputs[i]) {
@@ -187,7 +180,7 @@ void RecodeBeamSearch::ExtractBestPathAsWords(const TBOX& line_box,
   GenericVector<int> xcoords;
   GenericVector<const RecodeNode*> best_nodes;
   GenericVector<const RecodeNode*> second_nodes;
-  std::deque<std::pair<int,int>> best_choices;
+  std::deque<std::tuple<int, int>> best_choices;
   ExtractBestPaths(&best_nodes, &second_nodes);
   if (debug) {
     DebugPath(unicharset, best_nodes);
@@ -197,16 +190,14 @@ void RecodeBeamSearch::ExtractBestPathAsWords(const TBOX& line_box,
     DebugUnicharPath(unicharset, second_nodes, unichar_ids, certs, ratings,
                      xcoords);
   }
-  int current_char;
-  int timestepEnd = 0;
+  int timestepEnd= 0;
   //if lstm choice mode is required in granularity level 2 it stores the x
   //Coordinates of every chosen character to match the alternative choices to it
   if (lstm_choice_mode == 2) {
     ExtractPathAsUnicharIds(best_nodes, &unichar_ids, &certs, &ratings,
                             &xcoords, &best_choices);
     if (best_choices.size() > 0) {
-      current_char = best_choices.front().first;
-      timestepEnd = best_choices.front().second;
+      timestepEnd = std::get<1>(best_choices.front());
       best_choices.pop_front();
     }
   } else {
@@ -248,42 +239,37 @@ void RecodeBeamSearch::ExtractBestPathAsWords(const TBOX& line_box,
         word_res->timesteps.push_back(timesteps[i]);
       }
       timestepEnd = xcoords[word_end];
-    } else if (lstm_choice_mode == 2) {
+    } else if (lstm_choice_mode == 2){
+      // Accumulated Timesteps (choice mode 2 processing)
       float sum = 0;
       std::vector<std::pair<const char*, float>> choice_pairs;
       for (size_t i = timestepEnd; i < xcoords[word_end]; i++) {
         for (std::pair<const char*, float> choice : timesteps[i]) {
-          if (std::strcmp(choice.first, "") != 0) {
+          if (std::strcmp(choice.first, "")) {
             sum += choice.second;
             choice_pairs.push_back(choice);
           }
         }
-        if ((best_choices.size() > 0 && i == best_choices.front().second - 1)
+        if ((best_choices.size() > 0 && i == std::get<1>(best_choices.front()) - 1)
             || i == xcoords[word_end]-1) {
           std::map<const char*, float> summed_propabilities;
-          for (auto it = choice_pairs.begin(); it != choice_pairs.end(); ++it) {
-            summed_propabilities[it->first] += it->second;
+          for (auto & choice_pair : choice_pairs) {
+            summed_propabilities[choice_pair.first] += choice_pair.second;
           }
           std::vector<std::pair<const char*, float>> accumulated_timestep;
-          accumulated_timestep.push_back(std::pair<const char*,float>
-                                        (unicharset->id_to_unichar_ext
-                                        (current_char), 2.0));
-          int pos;
-          for (auto it = summed_propabilities.begin();
-               it != summed_propabilities.end(); ++it) {
+          for (auto& summed_propability : summed_propabilities) {
             if(sum == 0) break;
-            it->second/=sum;
-            pos = 0;
+            summed_propability.second/=sum;
+            size_t pos = 0;
             while (accumulated_timestep.size() > pos
-                   && accumulated_timestep[pos].second > it->second) {
+                   && accumulated_timestep[pos].second > summed_propability.second) {
               pos++;
             }
             accumulated_timestep.insert(accumulated_timestep.begin() + pos,
-                                        std::pair<const char*,float>(it->first,
-                                        it->second));
+                                        std::pair<const char*,float>(summed_propability.first,
+                                        summed_propability.second));
           }
           if (best_choices.size() > 0) {
-            current_char = best_choices.front().first;
             best_choices.pop_front();
           }
           choice_pairs.clear();
@@ -294,9 +280,9 @@ void RecodeBeamSearch::ExtractBestPathAsWords(const TBOX& line_box,
       timestepEnd = xcoords[word_end];
     }
     for (int i = word_start; i < word_end; ++i) {
-      BLOB_CHOICE_LIST* choices = new BLOB_CHOICE_LIST;
+      auto* choices = new BLOB_CHOICE_LIST;
       BLOB_CHOICE_IT bc_it(choices);
-      BLOB_CHOICE* choice = new BLOB_CHOICE(
+      auto* choice = new BLOB_CHOICE(
           unichar_ids[i], ratings[i], certs[i], -1, 1.0f,
           static_cast<float>(INT16_MAX), 0.0f, BCC_STATIC_CLASSIFIER);
       int col = i - word_start;
@@ -318,7 +304,7 @@ void RecodeBeamSearch::DebugBeams(const UNICHARSET& unicharset) const {
   for (int p = 0; p < beam_size_; ++p) {
     for (int d = 0; d < 2; ++d) {
       for (int c = 0; c < NC_COUNT; ++c) {
-        NodeContinuation cont = static_cast<NodeContinuation>(c);
+        auto cont = static_cast<NodeContinuation>(c);
         int index = BeamIndex(d, cont, 0);
         if (beam_[p]->beams_[index].empty()) continue;
         // Print all the best scoring nodes for each unichar found.
@@ -366,7 +352,7 @@ void RecodeBeamSearch::ExtractPathAsUnicharIds(
     const GenericVector<const RecodeNode*>& best_nodes,
     GenericVector<int>* unichar_ids, GenericVector<float>* certs,
     GenericVector<float>* ratings, GenericVector<int>* xcoords,
-    std::deque<std::pair<int, int>>* best_choices) {
+    std::deque<std::tuple<int, int>>* best_choices) {
   unichar_ids->truncate(0);
   certs->truncate(0);
   ratings->truncate(0);
@@ -375,6 +361,8 @@ void RecodeBeamSearch::ExtractPathAsUnicharIds(
   int t = 0;
   int width = best_nodes.size();
   while (t < width) {
+    int id;
+    int tposition;
     double certainty = 0.0;
     double rating = 0.0;
     while (t < width && best_nodes[t]->unichar_id == INVALID_UNICHAR_ID) {
@@ -396,7 +384,8 @@ void RecodeBeamSearch::ExtractPathAsUnicharIds(
       unichar_ids->push_back(unichar_id);
       xcoords->push_back(t);
       if (best_choices != nullptr) {
-        best_choices->push_back(std::pair<int, int>(unichar_id, t));
+        tposition = t;
+        id = unichar_id;
       }
       do {
         double cert = best_nodes[t++]->certainty;
@@ -414,6 +403,10 @@ void RecodeBeamSearch::ExtractPathAsUnicharIds(
       if (certainty < certs->back()) certs->back() = certainty;
       ratings->back() += rating;
     }
+    if (best_choices != nullptr) {
+      best_choices->push_back(
+          std::tuple<int, int>(id, tposition));
+    }
   }
   xcoords->push_back(width);
 }
@@ -445,7 +438,7 @@ WERD_RES* RecodeBeamSearch::InitializeWord(bool leading_space,
   // Make a fake word from the blobs.
   WERD* word = new WERD(&blobs, leading_space, nullptr);
   // Make a WERD_RES from the word.
-  WERD_RES* word_res = new WERD_RES(word);
+  auto* word_res = new WERD_RES(word);
   word_res->uch_set = unicharset;
   word_res->combination = true;  // Give it ownership of the word.
   word_res->space_certainty = space_certainty;
@@ -498,10 +491,10 @@ void RecodeBeamSearch::DecodeStep(const float* outputs, int t,
   if (t == 0) {
     // The first step can only use singles and initials.
     ContinueContext(nullptr, BeamIndex(false, NC_ANYTHING, 0), outputs, TN_TOP2,
-                    dict_ratio, cert_offset, worst_dict_cert, step);
+                    charset, dict_ratio, cert_offset, worst_dict_cert, step);
     if (dict_ != nullptr) {
-      ContinueContext(nullptr, BeamIndex(true, NC_ANYTHING, 0), outputs,
-                      TN_TOP2, dict_ratio, cert_offset, worst_dict_cert, step);
+      ContinueContext(nullptr, BeamIndex(true, NC_ANYTHING, 0), outputs, TN_TOP2,
+                      charset, dict_ratio, cert_offset, worst_dict_cert, step);
     }
   } else {
     RecodeBeam* prev = beam_[t - 1];
@@ -527,15 +520,14 @@ void RecodeBeamSearch::DecodeStep(const float* outputs, int t,
     // first, which may have an empty intersection with the valid codes, so we
     // fall back to the rest if the beam is empty.
     for (int tn = 0; tn < TN_COUNT && total_beam == 0; ++tn) {
-      TopNState top_n = static_cast<TopNState>(tn);
+      auto top_n = static_cast<TopNState>(tn);
       for (int index = 0; index < kNumBeams; ++index) {
         // Working backwards through the heaps doesn't guarantee that we see the
         // best first, but it comes before a lot of the worst, so it is slightly
         // more efficient than going forwards.
         for (int i = prev->beams_[index].size() - 1; i >= 0; --i) {
-          ContinueContext(&prev->beams_[index].get(i).data, index, outputs,
-                          top_n, dict_ratio, cert_offset, worst_dict_cert,
-                          step);
+          ContinueContext(&prev->beams_[index].get(i).data, index, outputs, top_n,
+                          charset, dict_ratio, cert_offset, worst_dict_cert, step);
         }
       }
       for (int index = 0; index < kNumBeams; ++index) {
@@ -562,7 +554,9 @@ void RecodeBeamSearch::DecodeStep(const float* outputs, int t,
 // choices for which top_n_flags[index] == top_n_flag.
 void RecodeBeamSearch::ContinueContext(const RecodeNode* prev, int index,
                                        const float* outputs,
-                                       TopNState top_n_flag, double dict_ratio,
+                                       TopNState top_n_flag,
+                                       const UNICHARSET* charset,
+                                       double dict_ratio,
                                        double cert_offset,
                                        double worst_dict_cert,
                                        RecodeBeam* step) {
@@ -625,6 +619,10 @@ void RecodeBeamSearch::ContinueContext(const RecodeNode* prev, int index,
       int unichar_id = recoder_.DecodeUnichar(full_code);
       // Map the null char to INVALID.
       if (length == 0 && code == null_char_) unichar_id = INVALID_UNICHAR_ID;
+      if (unichar_id != INVALID_UNICHAR_ID &&
+          charset != nullptr &&
+          !charset->get_enabled(unichar_id))
+        continue; // disabled by whitelist/blacklist
       ContinueUnichar(code, unichar_id, cert, worst_dict_cert, dict_ratio,
                       use_dawgs, NC_ANYTHING, prev, step);
       if (top_n_flag == TN_TOP2 && code != null_char_) {
@@ -756,7 +754,7 @@ void RecodeBeamSearch::ContinueDawg(int code, int unichar_id, float cert,
     return;  // Can't break words between space delimited chars.
   }
   DawgPositionVector initial_dawgs;
-  DawgPositionVector* updated_dawgs = new DawgPositionVector;
+  auto* updated_dawgs = new DawgPositionVector;
   DawgArgs dawg_args(&initial_dawgs, updated_dawgs, NO_PERM);
   bool word_start = false;
   if (uni_prev == nullptr) {
@@ -770,7 +768,7 @@ void RecodeBeamSearch::ContinueDawg(int code, int unichar_id, float cert,
   } else {
     return;  // Can't continue if not a dict word.
   }
-  PermuterType permuter = static_cast<PermuterType>(
+  auto permuter = static_cast<PermuterType>(
       dict_->def_letter_is_okay(&dawg_args,
                                 dict_->getUnicharset(), unichar_id, false));
   if (permuter != NO_PERM) {
@@ -804,7 +802,7 @@ void RecodeBeamSearch::PushInitialDawgIfBetter(int code, int unichar_id,
   float score = cert;
   if (prev != nullptr) score += prev->score;
   if (best_initial_dawg->code < 0 || score > best_initial_dawg->score) {
-    DawgPositionVector* initial_dawgs = new DawgPositionVector;
+    auto* initial_dawgs = new DawgPositionVector;
     dict_->default_dawgs(initial_dawgs, false);
     RecodeNode node(code, unichar_id, permuter, true, start, end, false, cert,
                     score, prev, initial_dawgs,
@@ -931,7 +929,7 @@ void RecodeBeamSearch::ExtractBestPaths(
   const RecodeBeam* last_beam = beam_[beam_size_ - 1];
   for (int c = 0; c < NC_COUNT; ++c) {
     if (c == NC_ONLY_DUP) continue;
-    NodeContinuation cont = static_cast<NodeContinuation>(c);
+    auto cont = static_cast<NodeContinuation>(c);
     for (int is_dawg = 0; is_dawg < 2; ++is_dawg) {
       int beam_index = BeamIndex(is_dawg, cont, 0);
       int heap_size = last_beam->beams_[beam_index].size();
