@@ -11,18 +11,17 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+#define _USE_MATH_DEFINES       // for M_PI
 #include "commontraining.h"
+#include <algorithm>
+#include <cmath>                // for M_PI
 
 #ifdef DISABLED_LEGACY_ENGINE
 
-#include <algorithm>
-#include <cmath>
-
 #include "params.h"
 #include "tessopt.h"
 #include "tprintf.h"
 
-
 INT_PARAM_FLAG(debug_level, 0, "Level of Trainer debugging");
 INT_PARAM_FLAG(load_images, 0, "Load images with tr files");
 STRING_PARAM_FLAG(configfile, "", "File to load more configs from");
@@ -34,7 +33,6 @@ STRING_PARAM_FLAG(O, "", "File to write unicharset to");
 STRING_PARAM_FLAG(output_trainer, "", "File to write trainer to");
 STRING_PARAM_FLAG(test_ch, "", "UTF8 test character string");
 
-
 /**
  * This routine parses the command line arguments that were
  * passed to the program and uses them to set relevant
@@ -44,7 +42,6 @@ STRING_PARAM_FLAG(test_ch, "", "UTF8 test character string");
  * - Config  current clustering parameters
  * @param argc number of command line arguments to parse
  * @param argv command line arguments
- * @return none
  * @note Exceptions: Illegal options terminate the program.
  */
 void ParseArguments(int* argc, char ***argv) {
@@ -60,9 +57,6 @@ void ParseArguments(int* argc, char ***argv) {
 
 #else
 
-#include <algorithm>
-#include <cmath>
-
 #include "allheaders.h"
 #include "ccutil.h"
 #include "classify.h"
@@ -71,7 +65,6 @@ void ParseArguments(int* argc, char ***argv) {
 #include "emalloc.h"
 #include "featdefs.h"
 #include "fontinfo.h"
-#include "globals.h"
 #include "intfeaturespace.h"
 #include "mastertrainer.h"
 #include "mf.h"
@@ -94,11 +87,11 @@ using tesseract::ShapeTable;
 // -M 0.625   -B 0.05   -I 1.0   -C 1e-6.
 CLUSTERCONFIG Config = { elliptical, 0.625, 0.05, 1.0, 1e-6, 0 };
 FEATURE_DEFS_STRUCT feature_defs;
-CCUtil ccutil;
+static CCUtil ccutil;
 
 INT_PARAM_FLAG(debug_level, 0, "Level of Trainer debugging");
-INT_PARAM_FLAG(load_images, 0, "Load images with tr files");
-STRING_PARAM_FLAG(configfile, "", "File to load more configs from");
+static INT_PARAM_FLAG(load_images, 0, "Load images with tr files");
+static STRING_PARAM_FLAG(configfile, "", "File to load more configs from");
 STRING_PARAM_FLAG(D, "", "Directory to write output files to");
 STRING_PARAM_FLAG(F, "font_properties", "File listing font properties");
 STRING_PARAM_FLAG(X, "", "File listing font xheights");
@@ -106,15 +99,15 @@ STRING_PARAM_FLAG(U, "unicharset", "File to load unicharset from");
 STRING_PARAM_FLAG(O, "", "File to write unicharset to");
 STRING_PARAM_FLAG(output_trainer, "", "File to write trainer to");
 STRING_PARAM_FLAG(test_ch, "", "UTF8 test character string");
-DOUBLE_PARAM_FLAG(clusterconfig_min_samples_fraction, Config.MinSamples,
-                  "Min number of samples per proto as % of total");
-DOUBLE_PARAM_FLAG(clusterconfig_max_illegal, Config.MaxIllegal,
-                  "Max percentage of samples in a cluster which have more"
-                  " than 1 feature in that cluster");
-DOUBLE_PARAM_FLAG(clusterconfig_independence, Config.Independence,
-                  "Desired independence between dimensions");
-DOUBLE_PARAM_FLAG(clusterconfig_confidence, Config.Confidence,
-                  "Desired confidence in prototypes created");
+static DOUBLE_PARAM_FLAG(clusterconfig_min_samples_fraction, Config.MinSamples,
+                         "Min number of samples per proto as % of total");
+static DOUBLE_PARAM_FLAG(clusterconfig_max_illegal, Config.MaxIllegal,
+                         "Max percentage of samples in a cluster which have more"
+                         " than 1 feature in that cluster");
+static DOUBLE_PARAM_FLAG(clusterconfig_independence, Config.Independence,
+                         "Desired independence between dimensions");
+static DOUBLE_PARAM_FLAG(clusterconfig_confidence, Config.Confidence,
+                         "Desired confidence in prototypes created");
 
 /**
  * This routine parses the command line arguments that were
@@ -125,7 +118,6 @@ DOUBLE_PARAM_FLAG(clusterconfig_confidence, Config.Confidence,
  * - Config  current clustering parameters
  * @param argc number of command line arguments to parse
  * @param argv command line arguments
- * @return none
  */
 void ParseArguments(int* argc, char ***argv) {
   STRING usage;
@@ -350,7 +342,7 @@ LABELEDLIST FindList(LIST List, char* Label) {
 
   iterate (List)
   {
-    LabeledList = (LABELEDLIST) first_node (List);
+    LabeledList = reinterpret_cast<LABELEDLIST>first_node (List);
     if (strcmp (LabeledList->Label, Label) == 0)
       return (LabeledList);
   }
@@ -369,8 +361,8 @@ LABELEDLIST FindList(LIST List, char* Label) {
 LABELEDLIST NewLabeledList(const char* Label) {
   LABELEDLIST LabeledList;
 
-  LabeledList = (LABELEDLIST) Emalloc (sizeof (LABELEDLISTNODE));
-  LabeledList->Label = (char*)Emalloc (strlen (Label)+1);
+  LabeledList = static_cast<LABELEDLIST>(Emalloc (sizeof (LABELEDLISTNODE)));
+  LabeledList->Label = static_cast<char*>(Emalloc (strlen (Label)+1));
   strcpy (LabeledList->Label, Label);
   LabeledList->List = NIL_LIST;
   LabeledList->SampleCount = 0;
@@ -393,8 +385,6 @@ LABELEDLIST NewLabeledList(const char* Label) {
  * @param max_samples
  * @param unicharset
  * @param training_samples
- * @return none
- * @note Globals: none
  */
 void ReadTrainingSamples(const FEATURE_DEFS_STRUCT& feature_definitions,
                          const char *feature_name, int max_samples,
@@ -456,8 +446,6 @@ void ReadTrainingSamples(const FEATURE_DEFS_STRUCT& feature_definitions,
  * This routine deallocates all of the space allocated to
  * the specified list of training samples.
  * @param CharList list of all fonts in document
- * @return none
- * @note Globals: none
  */
 void FreeTrainingSamples(LIST CharList) {
   LABELEDLIST char_sample;
@@ -466,10 +454,10 @@ void FreeTrainingSamples(LIST CharList) {
 
   LIST nodes = CharList;
   iterate(CharList) { /* iterate through all of the fonts */
-    char_sample = (LABELEDLIST) first_node(CharList);
+    char_sample = reinterpret_cast<LABELEDLIST>first_node(CharList);
     FeatureList = char_sample->List;
     iterate(FeatureList) { /* iterate through all of the classes */
-      FeatureSet = (FEATURE_SET) first_node(FeatureList);
+      FeatureSet = reinterpret_cast<FEATURE_SET>first_node(FeatureList);
       FreeFeatureSet(FeatureSet);
     }
     FreeLabeledList(char_sample);
@@ -484,7 +472,6 @@ void FreeTrainingSamples(LIST CharList) {
  * consumed by the items in the list.
  * @param LabeledList labeled list to be freed
  * @note Globals: none
- * @return none
  */
 void FreeLabeledList(LABELEDLIST LabeledList) {
   destroy(LabeledList->List);
@@ -523,9 +510,9 @@ CLUSTERER *SetUpForClustering(const FEATURE_DEFS_STRUCT &FeatureDefs,
   FeatureList = char_sample->List;
   CharID = 0;
   iterate(FeatureList) {
-    FeatureSet = (FEATURE_SET) first_node(FeatureList);
+    FeatureSet = reinterpret_cast<FEATURE_SET>first_node(FeatureList);
     for (i = 0; i < FeatureSet->MaxNumFeatures; i++) {
-      if (Sample == nullptr) Sample = (float*)Emalloc(N * sizeof(float));
+      if (Sample == nullptr) Sample = static_cast<float*>(Emalloc(N * sizeof(float)));
       for (j = 0; j < N; j++)
         Sample[j] = FeatureSet->Features[i]->Params[j];
       MakeSample (Clusterer, Sample, CharID);
@@ -546,7 +533,7 @@ void MergeInsignificantProtos(LIST ProtoList, const char* label,
 
   LIST pProtoList = ProtoList;
   iterate(pProtoList) {
-    Prototype = (PROTOTYPE *) first_node (pProtoList);
+    Prototype = reinterpret_cast<PROTOTYPE *>first_node (pProtoList);
     if (Prototype->Significant || Prototype->Merged)
       continue;
     float best_dist = 0.125;
@@ -554,7 +541,7 @@ void MergeInsignificantProtos(LIST ProtoList, const char* label,
     // Find the nearest alive prototype.
     LIST list_it = ProtoList;
     iterate(list_it) {
-      PROTOTYPE* test_p = (PROTOTYPE *) first_node (list_it);
+      PROTOTYPE* test_p = reinterpret_cast<PROTOTYPE *>first_node (list_it);
       if (test_p != Prototype && !test_p->Merged) {
         float dist = ComputeDistance(Clusterer->SampleSize,
                                      Clusterer->ParamDesc,
@@ -578,13 +565,13 @@ void MergeInsignificantProtos(LIST ProtoList, const char* label,
                                              best_match->Mean,
                                              best_match->Mean, Prototype->Mean);
       Prototype->NumSamples = 0;
-      Prototype->Merged = 1;
+      Prototype->Merged = true;
     } else if (best_match != nullptr) {
       if (debug)
         tprintf("Red proto at %g,%g matched a green one at %g,%g\n",
                 Prototype->Mean[0], Prototype->Mean[1],
                 best_match->Mean[0], best_match->Mean[1]);
-      Prototype->Merged = 1;
+      Prototype->Merged = true;
     }
   }
   // Mark significant those that now have enough samples.
@@ -592,7 +579,7 @@ void MergeInsignificantProtos(LIST ProtoList, const char* label,
     static_cast<int32_t>(clusterconfig->MinSamples * Clusterer->NumChar);
   pProtoList = ProtoList;
   iterate(pProtoList) {
-    Prototype = (PROTOTYPE *) first_node (pProtoList);
+    Prototype = reinterpret_cast<PROTOTYPE *>first_node (pProtoList);
     // Process insignificant protos that do not match a green one
     if (!Prototype->Significant && Prototype->NumSamples >= min_samples &&
         !Prototype->Merged) {
@@ -612,7 +599,7 @@ void CleanUpUnusedData(
 
   iterate(ProtoList)
   {
-    Prototype = (PROTOTYPE *) first_node (ProtoList);
+    Prototype = reinterpret_cast<PROTOTYPE *>first_node (ProtoList);
     free(Prototype->Variance.Elliptical);
     Prototype->Variance.Elliptical = nullptr;
     free(Prototype->Magnitude.Elliptical);
@@ -639,13 +626,13 @@ LIST RemoveInsignificantProtos(
   pProtoList = ProtoList;
   iterate(pProtoList)
   {
-    Proto = (PROTOTYPE *) first_node (pProtoList);
+    Proto = reinterpret_cast<PROTOTYPE *>first_node (pProtoList);
     if ((Proto->Significant && KeepSigProtos) ||
         (!Proto->Significant && KeepInsigProtos))
     {
-      NewProto = (PROTOTYPE *)Emalloc(sizeof(PROTOTYPE));
+      NewProto = static_cast<PROTOTYPE *>(Emalloc(sizeof(PROTOTYPE)));
 
-      NewProto->Mean = (float *)Emalloc(N * sizeof(float));
+      NewProto->Mean = static_cast<float *>(Emalloc(N * sizeof(float)));
       NewProto->Significant = Proto->Significant;
       NewProto->Style = Proto->Style;
       NewProto->NumSamples = Proto->NumSamples;
@@ -655,7 +642,7 @@ LIST RemoveInsignificantProtos(
       for (i=0; i < N; i++)
         NewProto->Mean[i] = Proto->Mean[i];
       if (Proto->Variance.Elliptical != nullptr) {
-        NewProto->Variance.Elliptical = (float *)Emalloc(N * sizeof(float));
+        NewProto->Variance.Elliptical = static_cast<float *>(Emalloc(N * sizeof(float)));
         for (i=0; i < N; i++)
           NewProto->Variance.Elliptical[i] = Proto->Variance.Elliptical[i];
       }
@@ -663,7 +650,7 @@ LIST RemoveInsignificantProtos(
         NewProto->Variance.Elliptical = nullptr;
       //---------------------------------------------
       if (Proto->Magnitude.Elliptical != nullptr) {
-        NewProto->Magnitude.Elliptical = (float *)Emalloc(N * sizeof(float));
+        NewProto->Magnitude.Elliptical = static_cast<float *>(Emalloc(N * sizeof(float)));
         for (i=0; i < N; i++)
           NewProto->Magnitude.Elliptical[i] = Proto->Magnitude.Elliptical[i];
       }
@@ -671,7 +658,7 @@ LIST RemoveInsignificantProtos(
         NewProto->Magnitude.Elliptical = nullptr;
       //------------------------------------------------
       if (Proto->Weight.Elliptical != nullptr) {
-        NewProto->Weight.Elliptical = (float *)Emalloc(N * sizeof(float));
+        NewProto->Weight.Elliptical = static_cast<float *>(Emalloc(N * sizeof(float)));
         for (i=0; i < N; i++)
           NewProto->Weight.Elliptical[i] = Proto->Weight.Elliptical[i];
       }
@@ -693,7 +680,7 @@ MERGE_CLASS FindClass(LIST List, const char* Label) {
 
   iterate (List)
   {
-    MergeClass = (MERGE_CLASS) first_node (List);
+    MergeClass = reinterpret_cast<MERGE_CLASS>first_node (List);
     if (strcmp (MergeClass->Label, Label) == 0)
       return (MergeClass);
   }
@@ -706,7 +693,7 @@ MERGE_CLASS NewLabeledClass(const char* Label) {
   MERGE_CLASS MergeClass;
 
   MergeClass = new MERGE_CLASS_NODE;
-  MergeClass->Label = (char*)Emalloc (strlen (Label)+1);
+  MergeClass->Label = static_cast<char*>(Emalloc (strlen (Label)+1));
   strcpy (MergeClass->Label, Label);
   MergeClass->Class = NewClass (MAX_NUM_PROTOS, MAX_NUM_CONFIGS);
   return (MergeClass);
@@ -718,8 +705,6 @@ MERGE_CLASS NewLabeledClass(const char* Label) {
  * This routine deallocates all of the space allocated to
  * the specified list of training samples.
  * @param ClassList list of all fonts in document
- * @return none
- * @note Globals: none
  */
 void FreeLabeledClassList(LIST ClassList) {
   MERGE_CLASS MergeClass;
@@ -727,7 +712,7 @@ void FreeLabeledClassList(LIST ClassList) {
   LIST nodes = ClassList;
   iterate(ClassList) /* iterate through all of the fonts */
   {
-    MergeClass = (MERGE_CLASS) first_node (ClassList);
+    MergeClass = reinterpret_cast<MERGE_CLASS>first_node (ClassList);
     free (MergeClass->Label);
     FreeClass(MergeClass->Class);
     delete MergeClass;
@@ -757,14 +742,14 @@ CLASS_STRUCT* SetUpForFloat2Int(const UNICHARSET& unicharset,
   iterate(LabeledClassList)
   {
     UnicityTableEqEq<int>   font_set;
-    MergeClass = (MERGE_CLASS) first_node (LabeledClassList);
+    MergeClass = reinterpret_cast<MERGE_CLASS>first_node (LabeledClassList);
     Class = &float_classes[unicharset.unichar_to_id(MergeClass->Label)];
     NumProtos = MergeClass->Class->NumProtos;
     NumConfigs = MergeClass->Class->NumConfigs;
     font_set.move(&MergeClass->Class->font_set);
     Class->NumProtos = NumProtos;
     Class->MaxNumProtos = NumProtos;
-    Class->Prototypes = (PROTO) Emalloc (sizeof(PROTO_STRUCT) * NumProtos);
+    Class->Prototypes = static_cast<PROTO>(Emalloc (sizeof(PROTO_STRUCT) * NumProtos));
     for(i=0; i < NumProtos; i++)
     {
       NewProto = ProtoIn(Class, i);
@@ -785,7 +770,7 @@ CLASS_STRUCT* SetUpForFloat2Int(const UNICHARSET& unicharset,
     Class->NumConfigs = NumConfigs;
     Class->MaxNumConfigs = NumConfigs;
     Class->font_set.move(&font_set);
-    Class->Configurations = (BIT_VECTOR*) Emalloc (sizeof(BIT_VECTOR) * NumConfigs);
+    Class->Configurations = static_cast<BIT_VECTOR*>(Emalloc (sizeof(BIT_VECTOR) * NumConfigs));
     NumWords = WordsInVectorOfSize(NumProtos);
     for(i=0; i < NumConfigs; i++)
     {
@@ -825,7 +810,7 @@ void FreeNormProtoList(LIST CharList)
   LIST nodes = CharList;
   iterate(CharList) /* iterate through all of the fonts */
   {
-    char_sample = (LABELEDLIST) first_node (CharList);
+    char_sample = reinterpret_cast<LABELEDLIST>first_node (CharList);
     FreeLabeledList (char_sample);
   }
   destroy(nodes);
@@ -844,7 +829,7 @@ void AddToNormProtosList(
   LabeledProtoList = NewLabeledList(CharName);
   iterate(ProtoList)
   {
-    Proto = (PROTOTYPE *) first_node (ProtoList);
+    Proto = reinterpret_cast<PROTOTYPE *>first_node (ProtoList);
     LabeledProtoList->List = push(LabeledProtoList->List, Proto);
   }
   *NormProtoList = push(*NormProtoList, LabeledProtoList);
@@ -856,7 +841,7 @@ int NumberOfProtos(LIST ProtoList, bool CountSigProtos,
   int N = 0;
   iterate(ProtoList)
   {
-    PROTOTYPE* Proto = (PROTOTYPE*)first_node(ProtoList);
+    PROTOTYPE* Proto = reinterpret_cast<PROTOTYPE*>first_node(ProtoList);
     if ((Proto->Significant && CountSigProtos) ||
         (!Proto->Significant && CountInsigProtos))
       N++;
