@@ -1,5 +1,19 @@
-#include "tesseract/ccutil/unichar.h"
+// (C) Copyright 2017, Google Inc.
+// Licensed under the Apache License, Version 2.0 (the "License");
+// you may not use this file except in compliance with the License.
+// You may obtain a copy of the License at
+// http://www.apache.org/licenses/LICENSE-2.0
+// Unless required by applicable law or agreed to in writing, software
+// distributed under the License is distributed on an "AS IS" BASIS,
+// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+// See the License for the specific language governing permissions and
+// limitations under the License.
 
+#include "include_gunit.h"
+#include "gmock/gmock.h"                // for testing::ElementsAreArray
+#include "unichar.h"
+
+using tesseract::char32;
 using tesseract::UNICHAR;
 
 namespace {
@@ -13,7 +27,7 @@ TEST(UnicharTest, Conversion) {
   // Check for round-trip conversion.
   std::vector<char32> utf32 = UNICHAR::UTF8ToUTF32(kUTF8Src);
   EXPECT_THAT(utf32, testing::ElementsAreArray(kUTF32Src));
-  string utf8 = UNICHAR::UTF32ToUTF8(utf32);
+  std::string utf8 = UNICHAR::UTF32ToUTF8(utf32);
   EXPECT_STREQ(kUTF8Src, utf8.c_str());
 }
 
@@ -25,7 +39,7 @@ TEST(UnicharTest, InvalidText) {
   std::vector<char32> utf32 = UNICHAR::UTF8ToUTF32(kInvalidUTF8);
   EXPECT_TRUE(utf32.empty());
   // Invalid utf32 produces an empty string.
-  string utf8 = UNICHAR::UTF32ToUTF8(kInvalidUTF32);
+  std::string utf8 = UNICHAR::UTF32ToUTF8(kInvalidUTF32);
   EXPECT_TRUE(utf8.empty());
 }
 
